@@ -10,7 +10,7 @@ require MARC::Spec::Comparisonstring;
 require MARC::Spec::Subspec;
 use namespace::clean;
 
-our $VERSION = '0.1.3';
+our $VERSION = '0.1.4';
 
 has spec => (
     is => 'rw',
@@ -120,7 +120,7 @@ sub _populate_subspecs {
             foreach my $or_subspec (@{$subspec}) {
                 push @or, $self->_match_subterms($or_subspec, $base);
             }
-            $spec->add_subspecs(\@or);
+            $spec->add_subspecs([\@or]);
         }
         else {
             $spec->add_subspec( $self->_match_subterms($subspec->[0], $base ) );
